@@ -1,14 +1,14 @@
 #!/usr/bin/env python
 
-import os, sys
-sys.path.append(os.path.abspath(os.path.dirname(__file__) + '/../src/'))
-
 import doctest
+import sys
 
 modules = [
+    'pyws.functions',
     'pyws.functions.register',
     'pyws.functions.args.types',
     'pyws.functions.args.types.complex',
+    'pyws.protocols.soap',
 ]
 
 if __name__ == '__main__':
